<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Media.Playlists

Windows Runtime (WinRT) APIs for for the `Windows.Media.Playlists` namespace.

This package provides the `winrt.windows.media.playlists` module.
